@@ -532,13 +532,15 @@ xfun_session_info <- function() {
 
 # given a path of a file (or dir) in a potential project (e.g., an R package),
 # figure out the project root
-proj_root <- function(path, file = '^DESCRIPTION$', pattern = '^Package: ') {
+proj_root <- function(path, file = '^DESCRIPTION$', pattern = '^Package: ', stop_when = NULL) {
   dir <- if (dir_exists(path)) path else dirname(path)
   if (same_path(dir, file.path(dir, '..'))) return()
   for (f in list.files(dir, file, full.names = TRUE)) {
     if (length(grep(pattern, read_utf8(f)))) return(dir)
   }
-  proj_root(dirname(dir), file, pattern)
+  if (is.function(stop_when) && stop_when(dir)) return()
+  dir <- normalize_path(dir)
+  proj_root(dirname(dir), file, pattern, stop_when)
 }
 
 
