@@ -7,8 +7,15 @@ test_that("toc has correct identifier", {
   tmp_file <- local_rmd_file(
     c("# 10 Section","","Sentence.","", "# Header","","Sentence ")
   )
+  pandoc_version <- if (pandoc_available("2.18.0.1")) {
+    "after-pandoc-2.18"
+  } else if (pandoc_available("2.18")) {
+    "pandoc-2.18"
+  } else {
+    "before-pandoc-2.18"
+  }
   res <- render(tmp_file, github_document(toc = TRUE, html_preview = FALSE))
-  expect_snapshot_file(res, "github-toc.md", compare = compare_file_text)
+  expect_snapshot_file(res, "github-toc.md", compare = compare_file_text, variant = pandoc_version)
 })
 
 test_that("toc has correct identifier also when sections are numbered ", {
@@ -17,8 +24,15 @@ test_that("toc has correct identifier also when sections are numbered ", {
   tmp_file <- local_rmd_file(
     c("# Section","","Sentence.","", "# Header","","Sentence ")
   )
+  pandoc_version <- if (pandoc_available("2.18.0.1")) {
+    "after-pandoc-2.18"
+  } else if (pandoc_available("2.18")) {
+    "pandoc-2.18"
+  } else {
+    "before-pandoc-2.18"
+  }
   res <- render(tmp_file, github_document(toc = TRUE, number_sections = TRUE, html_preview = FALSE))
-  expect_snapshot_file(res, "github-toc-numbered.md", compare = compare_file_text)
+  expect_snapshot_file(res, "github-toc-numbered.md", compare = compare_file_text, variant = pandoc_version)
 })
 
 
