@@ -1,7 +1,8 @@
 context("html_vignette format")
 
 .generate_temp_vignette <- function(title = NULL,
-                                    indexentry = NULL) {
+                                    indexentry = NULL,
+                                    envir = parent.frame()) {
   tmp_rmd <- tempfile("vignette-", fileext = ".Rmd")
   xfun::write_utf8(
     c("---",
@@ -16,13 +17,13 @@ context("html_vignette format")
       "---",
       "\n# This is a vignette"),
     tmp_rmd)
+  withr::defer(unlink(tmp_rmd), envir = envir)
   tmp_rmd
 }
 
 # https://github.com/rstudio/rmarkdown/pull/1789#issuecomment-616908700
 test_that("vignette_pre_processor warns against differences in vignette index entry and title", {
-  opts <- options(rmarkdown.html_vignette.check_title = TRUE)
-  on.exit(options(opts), add = TRUE)
+  withr::local_options(list(rmarkdown.html_vignette.check_title = TRUE))
   input_file <- .generate_temp_vignette('document title', 'vignette title')
   # only warns for R 3.6 and later
   if (getRversion() >= 3.6) {
@@ -30,5 +31,11 @@ test_that("vignette_pre_processor warns against differences in vignette index en
   } else {
     expect_null(vignette_pre_processor(input_file))
   }
-  unlink(input_file)
+})
+
+# https://github.com/rstudio/rmarkdown/issues/1978
+test_that("vignette_pre_processor correctly handles encoding", {
+  withr::local_options(list(rmarkdown.html_vignette.check_title = TRUE))
+  input_file <- .generate_temp_vignette('Données', 'Données')
+  expect_null(vignette_pre_processor(input_file))
 })
